==> blesta-5.10.2.zip: blesta/plugins/download_manager/language/it_it/download_manager_files.php <==
<?php
/**
 * Download Manager Files
 *
 * @package blesta
 * @subpackage blesta.language.it_it
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['DownloadManagerFiles.!error.file_id.exists'] = 'Il file da aggiornare non esiste.';
$lang['DownloadManagerFiles.!error.file_packages.format'] = 'Almeno un pacchetto selezionato non può essere aggiunto perché non esiste.';
$lang['DownloadManagerFiles.!error.permit_packages.format'] = 'L\'opzione di disponibilità del pacchetto è in un formato non valido.';
$lang['DownloadManagerFiles.!error.file_groups.format'] = 'Almeno un gruppo di clienti selezionato non può essere aggiunto perché non esiste.';
$lang['DownloadManagerFiles.!error.permit_client_groups.format'] = 'L\'opzione di disponibilità del gruppo di clienti è in un formato non valido.';
$lang['DownloadManagerFiles.!error.public.assignment'] = 'Il file deve essere disponibile al pubblico, ai gruppi di clienti o ai pacchetti.';
$lang['DownloadManagerFiles.!error.public.format'] = 'L\'opzione di disponibilità pubblica è in un formato non valido.';
$lang['DownloadManagerFiles.!error.file_name.format'] = 'Caricare un file o inserire un percorso valido per il file.';
$lang['DownloadManagerFiles.!error.name.empty'] = 'Inserire un nome per questo file.';
$lang['DownloadManagerFiles.!error.company_id.exists'] = 'ID azienda non valido.';
$lang['DownloadManagerFiles.!error.category_id.exists'] = 'Selezionare una categoria valida.';

==> blesta-5.11.4.zip: blesta/plugins/download_manager/language/it_it/download_manager_files.php <==
<?php
/**
 * Download Manager Files
 *
 * @package blesta
 * @subpackage blesta.language.it_it
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['DownloadManagerFiles.!error.file_id.exists'] = 'Il file da aggiornare non esiste.';
$lang['DownloadManagerFiles.!error.file_packages.format'] = 'Almeno un pacchetto selezionato non può essere aggiunto perché non esiste.';
$lang['DownloadManagerFiles.!error.permit_packages.format'] = 'L\'opzione di disponibilità del pacchetto è in un formato non valido.';
$lang['DownloadManagerFiles.!error.file_groups.format'] = 'Almeno un gruppo di clienti selezionato non può essere aggiunto perché non esiste.';
$lang['DownloadManagerFiles.!error.permit_client_groups.format'] = 'L\'opzione di disponibilità del gruppo di clienti è in un formato non valido.';
$lang['DownloadManagerFiles.!error.public.assignment'] = 'Il file deve essere disponibile al pubblico, ai gruppi di clienti o ai pacchetti.';
$lang['DownloadManagerFiles.!error.public.format'] = 'L\'opzione di disponibilità pubblica è in un formato non valido.';
$lang['DownloadManagerFiles.!error.file_name.format'] = 'Caricare un file o inserire un percorso valido per il file nella directory uploads.';
$lang['DownloadManagerFiles.!error.name.empty'] = 'Inserire un nome per questo file.';
$lang['DownloadManagerFiles.!error.company_id.exists'] = 'ID azienda non valido.';
$lang['DownloadManagerFiles.!error.category_id.exists'] = 'Selezionare una categoria valida.';
